==> aws-cdk-scala_2.13-0.14.0-sources.jar: io/burkard/cdk/services/ecr/assets/DockerImageAsset.scala <==
package io.burkard.cdk.services.ecr.assets

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object DockerImageAsset {

  def apply(
    internalResourceId: String,
    directory: String,
    buildArgs: Option[Map[String, String]] = None,
    invalidation: Option[software.amazon.awscdk.services.ecr.assets.DockerImageAssetInvalidationOptions] = None,
    extraHash: Option[String] = None,
    followSymlinks: Option[software.amazon.awscdk.SymlinkFollowMode] = None,
    file: Option[String] = None,
    networkMode: Option[software.amazon.awscdk.services.ecr.assets.NetworkMode] = None,
    target: Option[String] = None,
    exclude: Option[List[String]] = None,
    ignoreMode: Option[software.amazon.awscdk.IgnoreMode] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.ecr.assets.DockerImageAsset =
    software.amazon.awscdk.services.ecr.assets.DockerImageAsset.Builder
      .create(stackCtx, internalResourceId)
      .directory(directory)
      .buildArgs(buildArgs.map(_.asJava).orNull)
      .invalidation(invalidation.orNull)
      .extraHash(extraHash.orNull)
      .followSymlinks(followSymlinks.orNull)
      .file(file.orNull)
      .networkMode(networkMode.orNull)
      .target(target.orNull)
      .exclude(exclude.map(_.asJava).orNull)
      .ignoreMode(ignoreMode.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.21.0-sources.jar: io/burkard/cdk/services/ecr/assets/DockerImageAsset.scala <==
package io.burkard.cdk.services.ecr.assets

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object DockerImageAsset {

  def apply(
    internalResourceId: String,
    directory: String,
    buildArgs: Option[Map[String, String]] = None,
    invalidation: Option[software.amazon.awscdk.services.ecr.assets.DockerImageAssetInvalidationOptions] = None,
    extraHash: Option[String] = None,
    followSymlinks: Option[software.amazon.awscdk.SymlinkFollowMode] = None,
    file: Option[String] = None,
    networkMode: Option[software.amazon.awscdk.services.ecr.assets.NetworkMode] = None,
    target: Option[String] = None,
    exclude: Option[List[String]] = None,
    platform: Option[software.amazon.awscdk.services.ecr.assets.Platform] = None,
    ignoreMode: Option[software.amazon.awscdk.IgnoreMode] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.ecr.assets.DockerImageAsset =
    software.amazon.awscdk.services.ecr.assets.DockerImageAsset.Builder
      .create(stackCtx, internalResourceId)
      .directory(directory)
      .buildArgs(buildArgs.map(_.asJava).orNull)
      .invalidation(invalidation.orNull)
      .extraHash(extraHash.orNull)
      .followSymlinks(followSymlinks.orNull)
      .file(file.orNull)
      .networkMode(networkMode.orNull)
      .target(target.orNull)
      .exclude(exclude.map(_.asJava).orNull)
      .platform(platform.orNull)
      .ignoreMode(ignoreMode.orNull)
      .build()
}
